==> zither-1.1.15.tar.gz: zither_prj/zither/file_sets.c <==

#include<stdio.h>
#include<stdlib.h>
#include<sys/types.h>
#include<sys/stat.h>
#include<unistd.h>
#include<sys/socket.h>
#include<sys/wait.h>
#include<string.h>
#include<netinet/in.h>
#include<arpa/inet.h>
#include<pthread.h>

#include"zither.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"


int get_file(char *, char *, char);


/* ------------------ FILE SET 1.1.3 以の----------------- */
int file_sets( private_data_t * pd, char delim )
{
static int stat;
int inA = 1;
int count, cho;
char * tmp;

char * chA = (char *)calloc(IP_LEN, sizeof(char));
char * chB = (char *)calloc(IP_LEN, sizeof(char));
char * chC = (char *)calloc(IP_LEN, sizeof(char));

chA = safe_memcpy(chA, pd->rec.data, BUF_MAX);
count = strlen(pd->rec.data);
cho = mem_count(pd->rec.data,':');

stat = -1;
if( NULL != strchr(pd->rec.data,':') && 3 <= cho && (count - cho) > 3 && count > 7
    && 1 != mem_count(pd->rec.data, '#')){
   chB = safe_memcpy(chB, strtok_r(chA, ":", &tmp), BUF_MAX);
   chC = safe_memcpy(chC, 1 + strchr(pd->rec.data, ':'), BUF_MAX);
   rm_crlf(chC, (int)strlen(chC));
   inA = file_check(chB);
   stat = 1;
   switch(inA){
      case 1 : stat = get_file(pd->file.bat_filename, chC, (char)delim);
              break;  
      case 2 : stat = get_file(pd->file.scan_filename, chC, (char)delim);
              break;  
      case 3 : stat = get_file(pd->file.conf_filename, chC, (char)delim);
              break;  
      case 4 : stat = get_file(pd->file.stat_filename, chC, (char)delim);
              break;  
      default : stat = -1;
              break;
      }
   }

free(chA);
free(chB);
free(chC);

return(stat);
}







/* ------------ get_file --------------- */
int get_file(char * filename, char * data, char delim)
{
static int ret;
struct stat stat_buf;
FILE * fp;
int fd;

ret = 0;
if(0 == stat(filename, &stat_buf)){
   fprintf(stderr,"get_file(): It doesn't write it because there is a file. %s\n", filename);
   ret = -1;
   }
else {
   if((fp = fopen(filename, "w+"))!=NULL){
      fd = fileno(fp);
      swap_mem(data, (char)delim, '\n', (int)strlen(data));
      fprintf(fp,"%s",data);
      fclose(fp);
      }
   else{
      fprintf(stderr,"get_file(): new file Not open %s\n", filename);
      }
   fprintf(stderr,"get_file(): The client wrote it because there was no file. %s\n", filename);
   ret = 1;
   }

return(ret);
}

==> zither-1.2.6.tar.gz: zither_prj/zither/file_sets.c <==

#include<stdio.h>
#include<stdlib.h>
#include<sys/types.h>
#include<sys/stat.h>
#include<unistd.h>
#include<sys/socket.h>
#include<sys/wait.h>
#include<string.h>
#include<netinet/in.h>
#include<arpa/inet.h>
#include<pthread.h>

#include"zither.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"


int get_file(char *, char *, char);


/* ------------------ FILE SET 1.1.3 以の----------------- */
int file_sets( private_data_t * pd, char delim )
{
static int stat;
int inA = 1;
int count, cho;
char * tmp;

char * chA = (char *)calloc(IP_LEN, sizeof(char));
char * chB = (char *)calloc(IP_LEN, sizeof(char));
char * chC = (char *)calloc(IP_LEN, sizeof(char));

chA = safe_memcpy(chA, pd->rec.data, BUF_MAX);
count = strlen(pd->rec.data);
cho = mem_count(pd->rec.data,':');

stat = -1;
if( NULL != strchr(pd->rec.data,':') && 3 <= cho && (count - cho) > 3 && count > 7
    && 1 != mem_count(pd->rec.data, '#')){
   chB = safe_memcpy(chB, strtok_r(chA, ":", &tmp), BUF_MAX);
   chC = safe_memcpy(chC, 1 + strchr(pd->rec.data, ':'), BUF_MAX);
   rm_crlf(chC, (int)strlen(chC));
   inA = file_check(chB);
   stat = 1;
   switch(inA){
      case 1 : stat = get_file(pd->file.bat_filename, chC, (char)delim);
              break;  
      case 2 : stat = get_file(pd->file.scan_filename, chC, (char)delim);
              break;  
      case 3 : stat = get_file(pd->file.conf_filename, chC, (char)delim);
              break;  
      case 4 : stat = get_file(pd->file.stat_filename, chC, (char)delim);
              break;  
      default : stat = -1;
              break;
      }
   }

free(chA);
free(chB);
free(chC);

return(stat);
}







/* ------------ get_file --------------- */
int get_file(char * filename, char * data, char delim)
{
static int ret;
struct stat stat_buf;
FILE * fp;
int fd;

ret = 0;
if(0 == stat(filename, &stat_buf)){
   fprintf(stderr,"get_file(): It doesn't write it because there is a file. %s\n", filename);
   ret = -1;
   }
else {
   if((fp = fopen(filename, "w+"))!=NULL){
      fd = fileno(fp);
      swap_mem(data, (char)delim, '\n');
      fprintf(fp,"%s",data);
      fclose(fp);
      }
   else{
      fprintf(stderr,"get_file(): new file Not open %s\n", filename);
      }
   fprintf(stderr,"get_file(): The client wrote it because there was no file. %s\n", filename);
   ret = 1;
   }

return(ret);
}
